@@ -6,7 +6,6 @@ use base qw/OurNet::BBS::Base/;
 use fields qw/basepath board name dir hdrfile recno mtime btime _cache/;
 use subs qw/remove/;
 use vars qw/%chronos/;
-use File::stat;
 use POSIX;
 
 BEGIN {
@@ -38,7 +37,7 @@ sub new_id {
 
     unless (-e "$file/$self->{hdrfile}") {
         open _, ">$file/$self->{hdrfile}"
-          or die "cannot create $file/$self->{hdrfile}}";
+	    or die "cannot create $file/$self->{hdrfile}";
         close _;
     }
 
@@ -68,10 +67,10 @@ sub _refresh_body {
 
     my $file = join('/', $self->basedir, substr($self->{name}, -1), $self->{name});
 
-    return if $self->{btime} and stat($file)->mtime == $self->{btime}
+    return if $self->{btime} and (stat($file))[9] == $self->{btime}
                              and defined $self->{_cache}{body};
 
-    $self->{btime} = stat($file)->mtime;
+    $self->{btime} = (stat($file))[9];
     $self->{_cache}{date} ||= sprintf("%02d/%2d/%02d", substr((localtime)[5]+1900, -2), (localtime($self->{btime}))[4] + 1, (localtime($self->{btime}))[3]);
 
     local $/;
@@ -113,15 +112,15 @@ sub refresh_meta {
 
     my $file = join('/', $self->basedir, substr($self->{name}, -1), $self->{name});
     return unless -e $file;
-    $self->{btime} = stat($file)->mtime;
+    $self->{btime} = (stat($file))[9]; 
 
     $file = join('/', $self->basedir, $self->{hdrfile});
-    return if $self->{mtime} and stat($file)->mtime == $self->{mtime};
-    $self->{mtime} = stat($file)->mtime;
+    return if $self->{mtime} and (stat($file))[9] == $self->{mtime};
+    $self->{mtime} = (stat($file))[9];
 
     local $/ = \$packsize;
     open DIR, "$file" or die "can't read DIR file for $self->{board}: $!";
-    my $filesize = stat($file)->size;
+    my $filesize = (stat($file))[7];
 
     if (defined $self->{recno}) {
         seek DIR, $packsize * $self->{recno}, 0;
@@ -167,7 +166,7 @@ sub STORE {
         open _, ">$file" or die "cannot open $file";
         print _ $value;
         close _;
-        $self->{btime} = stat($file)->mtime;
+        $self->{btime} = (stat($file))[9];
         $self->{_cache}{$key} = $value;
     }
     else {
@@ -180,12 +179,13 @@ sub STORE {
         seek DIR, $packsize * $self->{recno}, 0;
         print DIR pack($packstring, @{$self->{_cache}}{@packlist});
         close DIR;
-        $self->{mtime} = stat($file)->mtime;
+        $self->{mtime} = (stat($file))[9];
     }
 }
-=head1
+
+=comment
 sub remove {
-die 'dont remove please';
+    die "don't remove please";
     my $self = shift;
     my $file = join('/', $self->basedir, $self->{hdrfile});
 
@@ -198,9 +198,9 @@ die 'dont remove please';
         seek DIR, 0, 0;
         read(DIR, $buf, $packsize * $self->{recno});
     }
-    if ($self->{recno} < (stat($file)->size / $packsize) - 1) {
+    if ($self->{recno} < ((stat($file))[7] / $packsize) - 1) {
         seek DIR, $packsize * ($self->{recno}+1), 0;
-        read(DIR, $buf, $packsize * (stat($file)->size - (($self->{recno}+1) * $packsize)));
+        read(DIR, $buf, $packsize * ((stat($file))[9] - (($self->{recno}+1) * $packsize)));
     }
 
     close DIR;
@@ -212,5 +212,6 @@ die 'dont remove please';
     return unlink join('/', $self->basedir, $self->{name});
 }
 =cut
+
 1;
 
